@@ -17,7 +17,7 @@ otherPORT.q = function (x, k, q1, q2, method=c("MO", "GH","MM"))
     stop("k is not specified")
   }
   
-  if (any(k < 1) || any(k > n-nq -1) || any(k == n-nq -1)  || !is.numeric(k)   || k != as.integer(k)  )
+  if (isTRUE(any(k < 1)) || isTRUE(any(k > n-nq -1)) || isTRUE(any(k == n-nq -1))  || !is.numeric(k)   || isTRUE(any(k != as.integer(k)))  )
   {
     stop("k must be greater than or equal to 1 and less than exceedance sample size.")
   }
@@ -54,4 +54,4 @@ otherPORT.q = function (x, k, q1, q2, method=c("MO", "GH","MM"))
   rownames(VaRest) = k 
   return(list(EVI=EVI.est, HQ=VaRest))  
   
-}
\ No newline at end of file
+}
